# Vectograph

Vectograph is an open-source software library for applying knowledge graph embedding approaches on tabular data. 
To this end, Vectograph enables users to converts tabular data into RDF knowledge graph and apply KGE approaches.

- [Framework](#Framework)
        
- [Installation](#installation)

## Installation
```
1) git clone https://github.com/dice-group/Vectograph.git
2) git clone https://github.com/dice-group/PYKE.git
3) conda create -n temp python=3.6 # Or be sure that your have Python at least 3.6.
4) conda activate temp
5) python example.py
```
